#
# spec file for package yast2-nfs-client
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           yast2-nfs-client
Version:        5.0.1
Release:        1.5
URL:            https://github.com/yast/yast-nfs-client
Summary:        YaST2 - NFS Configuration
License:        GPL-2.0-or-later
Group:          System/YaST

Source0:        %{name}-%{version}.tar.bz2

BuildRequires:  perl-XML-Writer
BuildRequires:  update-desktop-files
BuildRequires:  yast2-devtools >= 4.2.2
BuildRequires:  yast2-testsuite
# Replace PackageSystem with Package
BuildRequires:  yast2 >= 4.4.38
BuildRequires:  rubygem(%{rb_default_ruby_abi}:rspec)
#for install task
BuildRequires:  rubygem(%rb_default_ruby_abi:yast-rake)
# path_matching (RSpec argument matcher)
BuildRequires:  yast2-ruby-bindings >= 3.1.31
# Better integration with Partitioner
BuildRequires:  yast2-storage-ng >= 4.4.35
# Unfortunately we cannot move this to macros.yast,
# bcond within macros are ignored by osc/OBS.
%bcond_with yast_run_ci_tests
%if %{with yast_run_ci_tests}
BuildRequires:  rubygem(%{rb_default_ruby_abi}:yast-rake-ci)
%endif

# Replace PackageSystem with Package
Requires:       yast2 >= 4.4.38
#idmapd_conf agent
Requires:       yast2-nfs-common >= 2.24.0
# showmount, #150382, #286300
Recommends:     nfs-client
# Better integration with Partitioner
Requires:       yast2-storage-ng >= 4.4.35
Requires:       yast2-ruby-bindings >= 1.0.0
# bsc#1161687
Requires:       /usr/bin/killall

Provides:       yast2-config-network:/usr/lib/YaST2/clients/lan_nfs_client.ycp
Provides:       yast2-config-nfs
Provides:       yast2-config-nfs-devel
Provides:       yast2-trans-nfs

Obsoletes:      yast2-config-nfs
Obsoletes:      yast2-config-nfs-devel
Obsoletes:      yast2-trans-nfs

Supplements:    autoyast(nfs)

BuildArch:      noarch

%description
The YaST2 component for configuration of NFS. NFS stands for network
file system access. It allows access to files on remote machines.

%prep
%setup -q

%build

%check
%yast_check

%install
%yast_install
%yast_metainfo

%files
%{yast_yncludedir}
%{yast_clientdir}
%{yast_moduledir}
%{yast_moduledir}
%{yast_libdir}
%{yast_desktopdir}
%{yast_metainfodir}
%{yast_icondir}
%doc %{yast_docdir}
%{yast_schemadir}
%license COPYING

%changelog
* Fri Jun 14 2024 Michal Filka <mfilka@suse.com>
- bsc#1218158
  - dropped reading / writing domain from / to idmapd.conf
- 5.0.1
* Wed Aug 30 2023 Josef Reidinger <jreidinger@suse.cz>
- 5.0.0 (bsc#1185510)
* Tue Mar  7 2023 Ladislav Slezák <lslezak@suse.com>
- Fixed unit test to not read the values from the current system
  (bsc#1209007)
- 4.6.1
* Fri Mar  3 2023 Ladislav Slezák <lslezak@suse.cz>
- Bump version to 4.6.0 (bsc#1208913)
* Wed May 11 2022 Josef Reidinger <jreidinger@suse.com>
- Fix localization of NFS Version widget values (bsc#1198076)
- 4.5.1
* Wed Apr  6 2022 Ladislav Slezák <lslezak@suse.cz>
- Bump version to 4.5.0 (bsc#1198109)
* Fri Feb  4 2022 José Iván López González <jlopez@suse.com>
- Recover hosts caching (related to fate#318196).
* Wed Feb  2 2022 José Iván López González <jlopez@suse.com>
- Adapt code for a better integration with the storage Expert
  Partitioner (related to fate#318196).
- Provide a new NfsForm to be used from the Expert Partitioner and
  move code to yast-storage-ng.
- 4.4.4
* Tue Jan 25 2022 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Use Package module instead of PackageSystem (bsc#1194886).
- 4.4.3
* Mon Dec 13 2021 Georg Pfuetzenreuter <mail@georg-pfuetzenreuter.net>
- Adding /usr/bin/killall as a requirement (bsc#1161687)
- 4.4.2
* Tue Jun 29 2021 Josef Reidinger <jreidinger@suse.com>
- Support systemd mount options in fstab (bsc#1187781)
- 4.4.1
* Tue Apr 20 2021 Ladislav Slezák <lslezak@suse.cz>
- 4.4.0 (bsc#1185510)
* Thu Feb 18 2021 Josef Reidinger <jreidinger@suse.com>
- Adapted unit test to recent changes in Yast::Report (related to
  bsc#1179893).
- 4.3.3
* Mon Aug 10 2020 schubi@suse.de
- AutoYaST: Added supplements: autoyast(nfs) into the spec file
  in order to install this packages if the section has been defined
  in the AY configuration file (bsc#1146494).
- 4.3.2
* Tue May 12 2020 Josef Reidinger <jreidinger@suse.com>
- Autoyast schema: Allow optional types for string and map objects
  (bsc#1170886)
- 4.3.1
* Mon May 11 2020 Stefan Hundhammer <shundhammer@suse.com>
- Fixed crash when using [Cancel] in the "Add" dialog (bsc#1170447)
- 4.3.0
* Thu Feb  6 2020 José Iván López González <jlopez@suse.com>
- Kill rpcbind process if it was directly executed without using
  systemd (bsc#1161687).
- 4.2.7
* Thu Jan 23 2020 Josef Reidinger <jreidinger@suse.com>
- fix return code for cli `yast2 nfs list` (bsc#1150070)
- Add error message when delete failed due to not found entry
- 4.2.6
* Fri Jan 17 2020 José Iván López González <jlopez@suse.com>
- Delegates mount/unmount actions to yast2-storage-ng.
- Keeps mount point status for existing shares.
- Adds an asterisk to mount point for unmounted entries.
- Related to bsc#1006815, bsc#1151426, bsc#1060159.
- 4.2.5
* Wed Jan  8 2020 David Diaz <dgonzalez@suse.com>
- Avoids displaying phantom NFS entries adding an action to
  refresh the UI (related to bsc#1156446).
- 4.2.4
* Wed Oct 30 2019 Knut Anderssen <kanderssen@suse.com>
- Removed nfsidmap hardcoded dependency once libnfsidmap was merged
  into nfs-utils and a separate package should not be needed
  anymore (bsc#1150807, bsc#1153568)
- 4.2.3
* Tue Aug 27 2019 schubi@suse.de
- Set X-SuSE-YaST-AutoInstResource in desktop file (bsc#144894).
- 4.2.2
* Thu Aug 22 2019 schubi@suse.de
- Using rb_default_ruby_abi tag in the spec file in order to
  handle several ruby versions (bsc#1146403).
- 4.2.1
* Fri May 31 2019 Stasiek Michalski <hellcp@mailbox.org>
- Add metainfo (fate#319035)
- Revamp spec
- Replace GenericName with Comment
- 4.2.0
* Wed Feb 27 2019 mvidner@suse.com
- Use /sbin/rpcinfo only, /usr/sbin/rpcinfo is gone (bsc#1127138).
- 4.1.5
* Fri Dec 28 2018 schubi@suse.de
- Handle NFS version 4.2 (bsc#1118779).
- 4.1.4
* Tue Dec 11 2018 jreidinger@suse.com
- always use absolute path to binaries (bsc#1118291)
- properly escape shell arguments (bsc#1118291)
- 4.1.3
* Thu Nov 29 2018 Noah Davis <noahadvs@gmail.com>
- Provide icon with module (boo#1109310)
- 4.1.2
* Tue Nov 27 2018 jreidinger@suse.com
- fix build failure caused by changes in storage-ng
  (related to change done for bsc#1088426)
- 4.1.1
* Tue Oct 16 2018 schubi@suse.de
- Added license file to spec.
* Thu Aug 23 2018 jreidinger@suse.com
- do not crash when nfs version is written as 4.0 instead of 4
  (bsc#1105674)
- 4.1.0
* Wed Aug 22 2018 schubi@suse.de
- Switched license in spec file from SPDX2 to SPDX3 format.
* Wed Jun 27 2018 schubi@suse.de
- Added additional searchkeys to desktop file (fate#321043).
- 4.0.7
* Fri May 18 2018 ancor@suse.com
- Fixed a bug preventing some strings (introduced while fixing
  bsc#1088426) to be translated.
- Do not crash when 'edit' button is pressed in the partitioner
  if there are no NFS entries (affects installation, part of
  fate#318196).
- When executed standalone (not embedded in the Partitioner),
  use storage-ng to read and write /etc/fstab, instead of the old
  buggy parser (bsc#429326, bsc#1064437).
- 4.0.6
* Fri Apr  6 2018 ancor@suse.com
- Use only nfsvers (or its alias) to specify the version of the
  NFS protocol, instead of the legacy nfs4 (vfstype) and
  minorversion (bsc#1088426).
- Detect legacy entries and warn the user.
- 4.0.5
* Tue Apr  3 2018 ancor@suse.com
- Command line interface: display correct content in the 'Options'
  column (bsc#1087826) when listing.
- Command line interface: updated help about the 'type' option.
- 4.0.4
* Tue Feb 27 2018 knut.anderssen@suse.com
- Fix a missing definition of firewalld method (bsc#1082919)
- 4.0.3
* Fri Feb 23 2018 lslezak@suse.cz
- During installation do not check whether the portmapper package
  is installed, fixed error handling when scanning the NFS exports
  fails (bsc#1079624)
- 4.0.2
* Thu Feb  1 2018 knut.anderssen@suse.com
- Replace SuSEFirewall2 by firewalld (fate#323460)
- 4.0.1
* Fri Nov  3 2017 knut.anderssen@suse.com
- Fix teststuite once SuSEFirewall2 is being replaced by firewalld
  (fate#323460)
- 4.0.0
* Mon Jun  6 2016 igonzalezsosa@suse.com
- Stop generating autodocs (fate#320356)
- Add a conditional BuildRequires to allow using Jenkins for
  continuous integration (lslezak@suse.cz)
- 3.1.17
* Mon Jul 20 2015 mvidner@suse.com
- Do not block an update of nfs-utils (boo#911986)
- 3.1.16
* Mon Apr  6 2015 ancor@suse.com
- Consider path dependencies between mount points, allowing eg.
  a local mount on top of an NFS mount point (bsc#922307).
- 3.1.15
* Tue Feb 24 2015 kmroz@suse.com
- Fix crash when accessing certain variables outside their block
  local scope. (bnc#919061)
* Thu Jan  8 2015 mvidner@suse.com
- Used Rubocop to enforce a consistent coding style.
- 3.1.13
* Thu Dec  4 2014 jreidinger@suse.com
- remove X-KDE-Library from desktop file (bnc#899104)
* Tue Nov 18 2014 lslezak@suse.cz
- fixed string substitution in a translated message
* Fri Nov  7 2014 locilka@suse.com
- Removed obsolete service (nfsboot) handling (bnc#867766)
- 3.1.10
* Thu Sep  4 2014 mvidner@suse.com
- Use a more flexible rubygem requirement syntax (bnc#895069)
- 3.1.9
* Wed Aug  6 2014 ancor@suse.com
- Don't display 'NFS Settings' tab when called from partitioner
  (bnc#890410)
- 3.1.8
* Thu Jul 31 2014 cwh@suse.com
- Added 'fsc' to the list of valid negatable options (bnc#873142)
- 3.1.7
* Wed Jul 16 2014 aschnell@suse.de
- allow mount option bsize (bnc#887369)
- 3.1.6
* Wed May 21 2014 mvidner@suse.com
- Fix building with nfs-utils-1.3.0 (bnc#878875).
- 3.1.5
* Mon May  5 2014 locilka@suse.com
- Obsolete Service.Status replaced with new Service.active?
- 3.1.4
* Fri Mar 28 2014 vmoravec@suse.com
- Fix failing tests again
- 3.1.3
* Wed Mar 12 2014 vmoravec@suse.com
- Fix failing tests
- 3.1.2
* Mon Nov 11 2013 locilka@suse.com
- Added missing mount options (bnc#848768)
- Refactored NfsOptions library
- 3.1.1
* Thu Sep 26 2013 lslezak@suse.cz
- do not use *.spec.in template, use *.spec file with RPM macros
  instead
- 3.1.0
* Fri Sep 20 2013 lslezak@suse.cz
- fixed syntax error in nfs.rnc (bnc#841550)
- 3.0.2
* Fri Sep 13 2013 mvidner@suse.com
- merged changes from SLE11-SP3
  - refactored the last change following a late review
    (FATE#312242, bnc#820989)
  - AutoYaST: fix to allow NFS4 options (FATE#312242, bnc#457981)
  - added option for enabling NFS4 GSS (FATE#312242, bnc#681190)
  - Added minorversion=1 for pNFS, NFS4.1 (FATE#312259).
  - enable compiling, testing, packaging from the WC (bnc#790490)
- merged changelogs from SLE-SP3 for changes
  that already are in this branch
  - fix enablement of NFSv4 in autoyast (bnc#684859)
  - allow to set version of nfs on command line and also fix passing
    default value (bnc#681275)
  - Consistent setting of widget focus esp. when embedded in partitioner
    (bnc#435992)
- 3.0.1
* Wed Jul 31 2013 yast-devel@opensuse.org
- converted from YCP to Ruby by YCP Killer
  (https://github.com/yast/ycp-killer)
- version 3.0.0
* Wed Jun 26 2013 lslezak@suse.cz
- updated reading/writing /etc/idmapd.conf file (SCR agent switched
  from Limal backend to ini-agent)
- 2.24.1
* Mon May 20 2013 locilka@suse.com
- Testsuites adapted to changes in Service module (bnc#807507)
- 2.24.0
* Thu Jan  3 2013 locilka@suse.com
- Testsuites adapted to switching Service module to systemd
  (yast2-2.23.15)
- Testsuite adapted to one single SuSEfirewall2 service
  (yast2-2.23.17)
- 2.21.9
* Thu Sep 20 2012 mfilka@suse.com
- added support for IPv6 in square brackets
- expanded testsuite for IPv6 checks
- bnc#719538
- 2.21.8
* Thu Aug 23 2012 mfilka@suse.com
- added support for comment, nofail fstab options
- bnc#776149
- 2.21.7
* Thu May  3 2012 mfilka@suse.com
- added option for enabling NFS4 GSS - bnc#681190
- 2.21.6
* Thu Mar 29 2012 jsuchome@suse.cz
- merged proofread texts
* Fri Feb 24 2012 mfilka@suse.com
- fixed testsuite
* Fri Feb 17 2012 mfilka@suse.com
- IPv6 addresses supported - bnc#719538
- updated testsuite
- 2.21.5
* Thu Feb 16 2012 mfilka@suse.com
- removed some dead code, whitespaces
* Thu Feb 16 2012 mfilka@suse.com
- autoinstallation fails to enable portmapper/rpcbind service - bnc#744357
- 2.21.4
* Thu Feb 16 2012 mfilka@suse.com
- accepted comments from earlier review.
- some formatting
- 2.21.4
* Wed Feb  8 2012 mfilka@suse.com
- Base server hostname combobox on existing values - bnc#547983
* Wed Dec  7 2011 coolo@suse.com
- fix license to be in spdx.org format
* Thu Nov  3 2011 locilka@suse.cz
- Fixed testsuites
- 2.21.2
* Wed Sep 21 2011 visnov@suse.cz
- set dialog title
- set proper dependency on yast2
- 2.21.1
* Fri Sep  9 2011 lslezak@suse.cz
- updated testsuite (systemd adaptation)
- 2.21.0
* Fri Aug  5 2011 tgoettlicher@suse.de
- fixed .desktop file (bnc #681249)
* Tue Jun 21 2011 jreidinger@suse.cz
- Fixed attempt to install rpmbind to inst-sys during installation
  (bnc#621197)
* Wed May 26 2010 kmachalkova@suse.cz
- Fixed handling of return symbols (buggy patch for bnc#589541, now
  bnc#608166)
- 2.19.3
* Mon Mar 22 2010 juhliarik@suse.cz
- added fix for problem with OK button (bnc#589541)
- 2.19.2
* Thu Feb  4 2010 kmachalkova@suse.cz
- New structure of <nfs> section of AY profiles to allow setting up
  global vars (bnc#457981)
- Some style fixes - use ButtonBoxes, use OK-Cancel dialog
  (bnc#571958)
- 2.19.1
* Mon Jan 18 2010 aschnell@suse.de
- adapted to NFS4 support in yast2-storage
- 2.19.0
* Wed Jan 13 2010 kmachalkova@suse.cz
- Adjusted .desktop file(s) to wrap /sbin/yast2/ calls in xdg-su
  where root privileges are needed, removed X-KDE-SubstituteUID key
  (bnc#540627)
* Wed Apr  8 2009 kmachalkova@suse.cz
- Do not use ag_showexports to show nfsv4-shared dirs on a server,
  use Nfs::Mount and show directory listing instead (bnc#466454)
- 2.18.0
* Thu Dec 11 2008 kmachalkova@suse.cz
- Missing strings marked for translation (bnc#449199)
- Speed up the lookup of available NFS servers on LAN - use rpcbind's
  rpcinfo (bnc#450056)
- Show a warning pop-up if no NFS servers on LAN are found because
  of SuSEFirewall (bnc#450056)
- Ground for NFS share renaming (changing server name) in partitioner
- 2.17.10
* Mon Nov 24 2008 kmachalkova@suse.cz
- Do not include nfsv4 shares into non-nfs entries :) (bnc#446161)
- Button re-labelling to comply to style-guide (bnc#440528)
- 2.17.9
* Fri Oct 31 2008 kmachalkova@suse.cz
- Pass no data to the partitioner if the user decides to cancel
  add/edit/delete NFS share operation
- Correct AY backwards compatibility code if 'vfstype' key is missing
  on Import - assume plain nfs in that case (bnc#438497)
- 2.17.8
* Wed Oct 29 2008 kmachalkova@suse.cz
- Correct enabling/disabling of edit and delete buttons depending
  on # of NFS shares (bnc#438665)
- Initialize only non-fstab NFS settings (firewall, sysconfig, idmapd)
  if the client is run embedded in the partitioner (bnc#436897)
- 2.17.7
* Mon Oct 20 2008 kmachalkova@suse.cz
- Un-HTML-ize help text (bnc#432800)
- ag_showexports (+ related scrconf file) moved to yast2 base
  package(bnc#257910)
- 2.17.6
* Thu Oct  9 2008 jsuchome@suse.cz
- fixed failing testsuite (Service.ycp)
- 2.17.5
* Tue Sep 23 2008 kmachalkova@suse.cz
- Use rpcbind instead of portmap (preferably, if not there, fall
  back to portmap) (bnc#423026)
- Prompt user for confirmation of aborting the module if changes were
  made (Get/SetModified)
- 2.17.4
* Mon Sep  8 2008 kmachalkova@suse.cz
- Necessary changes for having NFS read-write from partitioner
  (FaTE#303326)
- Prompt user for confirmation of deleting NFS share
- Make help texts accesible from outside (and make them tab-specific)
- Support for reading/writing of /etc/idmapd.conf ( -> added
  dependency on yast2-nfs-common)(bnc#387088)
- 2.17.3
* Sun Aug 24 2008 ro@suse.de
- fix build
* Thu Aug 14 2008 kmachalkova@suse.cz
- First steps to integrate nfs-client into partitioner (added a client
  making esp. UI accesible from other modules) (FaTE#303326)
- 2.17.2
* Fri Aug  8 2008 kmachalkova@suse.cz
- Configuration dialog split into two tabs: fstab entries and settings
- Extended list of supported nfs(4) mount options
- 2.17.1
* Wed Aug  6 2008 kmachalkova@suse.cz
- Create correct fstab entries when importing data from AY profile
  (regression from FaTE #302031 - now we need to store also fstype
  info - nfs vs. nfsv4) (bnc#395850)
- 2.17.0
* Fri May 16 2008 jsrain@suse.cz
- added categories Settings and System into desktop file
  (bnc #382778)
* Tue Apr 15 2008 kmachalkova@suse.cz
- Support for mounting nfsv4 shares (FaTE #302031)
- 2.16.1
* Fri Apr 11 2008 kmachalkova@suse.cz
- Propose default hostname for newly added server (nfs.current.domain)
  (FaTE #302863)
- 2.16.0
* Mon Mar 17 2008 jsrain@suse.cz
- added 'StartupNotify=true' to the desktop file (bnc #304964)
* Mon Aug 20 2007 mvidner@suse.cz
- Recommend nfs-client.rpm because nfs-utils.rpm got split (#286300).
- 2.15.0
* Fri May 25 2007 jsrain@suse.cz
- removed outdated translations from .desktop-files (#271209)
* Mon Nov 20 2006 mvidner@suse.cz
- Have all yast packages with 2.14.x in OS-10.2.
- 2.14.0
* Fri Oct 13 2006 mvidner@suse.cz
- Recommend nfs-utils for showmount (#150382).
- Align table editing buttons to the left (#211570).
- 2.13.5
* Mon Sep 11 2006 mvidner@suse.cz
- Fixed Progress nesting (#202351).
- Using autodocs-ycp.ami (with parentheses for automake-1.9.6).
- 2.13.4
* Tue Mar  7 2006 mvidner@suse.cz
- Converted neededforbuild to BuildRequires
  and removed yast2-devel-packages.
- 2.13.3
* Mon Jan 16 2006 mvidner@suse.cz
- Again adjusted test cases for NetworkManager related changes (~#135595).
- 2.13.2
* Thu Jan  5 2006 mvidner@suse.cz
- Adjusted testsuite for changes in firewall code.
- 2.13.1
* Fri Sep 23 2005 mvidner@suse.cz
- Moved RNC schema from autoyast2.rpm.
- 2.13.0
* Fri Aug 12 2005 mvidner@suse.cz
- Do not report error if no shares were mounted because of "noauto"
  (#74597).
- More robust parsing of showexports -e (#91184).
- Fixed check_ycp errors. Added comments for translators and ycpdoc.
- 2.12.3
* Wed May 18 2005 mvidner@suse.cz
- Texts proofread by rwalter.
- 2.12.2
* Fri Apr 22 2005 mvidner@suse.cz
- Updated the list of valid mount options to include "users" (#74718).
- 2.12.1
* Wed Mar 16 2005 mvidner@suse.cz
- Recent releases of SUSE Linux ignore ICMP broadcasts,
  so use RPC broadcasts for finding NFS servers (#71064).
- 2.11.7
* Thu Feb 10 2005 mvidner@suse.cz
- Another testsuite adjustment for firewall.
- 2.11.6
* Mon Feb  7 2005 mvidner@suse.cz
- Merged proofread texts.
- 2.11.5
* Mon Jan 31 2005 mvidner@suse.cz
- Adjusted testsuite for changes in firewall (build fix).
- 2.11.4
* Fri Jan 14 2005 jsuchome@suse.cz
- added command line interface functionality
- 2.11.3
* Mon Jan  3 2005 mvidner@suse.cz
- Adjusted for firewall's move to yast2.rpm.
- Using Progress::set.
- 2.11.2
* Thu Nov  4 2004 mvidner@suse.cz
- Replaced selects by brackets, fixing build.
- 2.11.1
* Wed Sep 15 2004 mvidner@suse.cz
- Use Package instead of Require.
- 2.10.5
* Tue Sep 14 2004 jsrain@suse.cz
- adapted testsuite to more changes in yast2-firewall
- 2.10.4
* Mon Sep  6 2004 mvidner@suse.cz
- Adjusted testsuite to changes in yast2-firewall (#44650).
- 2.10.3
* Mon Aug 30 2004 nashif@suse.de
- use modified flag (#43904)
* Fri Aug 27 2004 mvidner@suse.cz
- Added Open Firewall button.
- 2.10.1
* Mon Jun 21 2004 mvidner@suse.cz
- Added "testedfiles" to test cases to make it work with the new testsuite.
- Added a skeleton of the command line interface.
- 2.10.0
* Fri Apr  2 2004 mvidner@suse.cz
- changed license to GPL
- 2.9.11
* Wed Mar 31 2004 mvidner@suse.cz
- use nfsboot (sm_notify) instead of nfslock (rpc.statd) (#36737)
- 2.9.10
* Mon Mar 15 2004 mvidner@suse.cz
- fixed canceling Abort (#35991)
- tell the user if showmount is missing
- re-enabled testsuite
- 2.9.9
* Wed Mar 10 2004 kkaempf@suse.de
- disable testsuite
- 2.9.8
* Mon Mar  8 2004 lslezak@suse.cz
- use Sequencer::
- set icon
- version 2.9.7
* Fri Mar  5 2004 mvidner@suse.cz
- added type information (lslezak)
- 2.9.6
* Fri Feb 20 2004 lslezak@suse.cz
- start/stop nfslock service (#34151)
- use module Service::
- NI fixes (data types)
- testsuite update
- version 2.9.5
* Thu Feb 19 2004 lslezak@suse.cz
- removed yast2-packager from neededforbuild
- version 2.9.4
* Fri Feb 13 2004 lslezak@suse.cz
- NI fixes (backquote in agent, nil checking, removed globals)
- version 2.9.3
* Tue Feb 10 2004 lslezak@suse.cz
- removed *.y2cc file
- version 2.9.2
* Tue Feb  3 2004 lslezak@suse.cz
- testsuite: NI fixes, update
- version 2.9.1
* Thu Nov 20 2003 lslezak@suse.cz
- use UI:: file popup dialog
- version 2.9.0
* Thu Sep 11 2003 nashif@suse.de
- #30291: return list of required packages for autoinstallation
* Fri Sep  5 2003 lslezak@suse.de
- merged texts from proofread
- version 2.8.5
* Thu Aug 14 2003 jsuchome@suse.de
- added writing progress bar (due to #28729)
- 2.8.4
* Mon Aug 11 2003 lslezak@suse.cz
- new Mount and Unmount functions
- added yast2-packager to neededforbuild
- merged proofread texts
- version 2.8.3
* Mon Aug  4 2003 mvidner@suse.cz
- Kicked the "Really save?" and "Successfully saved" popups (#28322).
- Added desktop file (supersedes y2cc file).
- 2.8.2
* Fri Jun 20 2003 mvidner@suse.cz
- Using Require, Label and Popup.
- 2.8.1
* Fri Mar 28 2003 mvidner@suse.de
- Made the host browsing list display only NFS servers
  instead of all hosts on the LAN.
- Added a button to select from a list of exported directories
  of a NFS server.
- 2.8.0
* Mon Mar  3 2003 mvidner@suse.de
- Import accepts empty list and can reset settings (nashif).
- 2.7.3
* Wed Feb 12 2003 mvidner@suse.de
- Changed _auto::Result to Export (nashif).
- 2.7.2
* Mon Feb  3 2003 mvidner@suse.de
- Added Read to _auto (nashif).
- 2.7.1
* Mon Jan 20 2003 mvidner@suse.de
- Using the new *_auto dispatcher (nashif).
- Added function key shortcuts in ncurses.
- 2.7.0
* Mon Aug 26 2002 mvidner@suse.cz
- Make "yast2 nfs-client" invoke "yast2 nfs" (#17570).
- 2.6.11
* Sun Aug 11 2002 mvidner@suse.cz
- Let the table keep the keyboard focus (#16116 workaround).
- Fixed autoyast writing (nashif).
- 2.6.10
* Wed Jul 31 2002 mvidner@suse.cz
- Added comments for translators
- yast2-runlevel is no longer required.
- Updated screenshots
- 2.6.9
* Wed Jul 17 2002 mvidner@suse.cz
- Allow directories with spaces (#15524).
- 2.6.8
* Fri Jul 12 2002 arvin@suse.de
- use proper namespace for Args and CallFunction (#16776)
* Fri Jul 12 2002 mvidner@suse.cz
- Fixed dependencies, using devtools 2.6.6.
- 2.6.6
* Thu Jul  4 2002 arvin@suse.de
- moved non binary files to /usr/share/YaST2
* Fri Jun 28 2002 mvidner@suse.cz
- Renamed to "yast2-nfs-client".
- 2.6.3
* Wed Jun 26 2002 mvidner@suse.cz
- Pot file included.
- Removed dependency on translation package.
- Adapted to changed any-agent interface.
- 2.6.2
* Mon May 27 2002 mvidner@suse.cz
- Current autoyast interface (nashif)
- WM close button works as Abort
- Fix for automake 1.6
- 2.6.1
* Fri Feb 15 2002 mvidner@suse.cz
- Another proofreading.
- 2.5.10
* Mon Feb 11 2002 mvidner@suse.cz
- 'Finish' button does not change to 'Next'. Help fixed accordingly.
- Added SetFocus to input popups.
- 2.5.9
* Wed Jan 30 2002 mvidner@suse.cz
- Had the English texts proofread.
- 2.5.8
* Mon Jan 28 2002 mvidner@suse.cz
- Autoinst: fixed map keys.
- Autoinst: uses WriteOnly.
- 2.5.7
* Fri Jan 18 2002 mvidner@suse.cz
- SetFocus to the invalid input field. (bug #12323).
- Delete and activation fixed (module conversion bugs).
- Using Report::
- 2.5.6
* Wed Jan  9 2002 mvidner@suse.cz
- Removed old menu entry.
- 2.5.5
* Mon Dec 17 2001 mvidner@suse.cz
- Added an autoinstalation client.
- 2.5.4
* Tue Dec  4 2001 mvidner@suse.cz
- Added default values for selects.
- 2.5.3
* Wed Nov 28 2001 mvidner@suse.cz
- Converted to a Module.
- Migrated to y2autoconf and create-spec.
- 2.5.2
* Tue Nov 13 2001 mvidner@suse.cz
- Added default values for lookups.
- 2.5.1
* Thu Sep 20 2001 mvidner@suse.cz
- Fixed #11079: noauto and other generic options were refused.
- Also correctly says Wrong option instead of Wrong option format
- and strips spaces instead of giving a confusing error.
- 2.4.12
* Fri Sep 14 2001 mvidner@suse.cz
- Added missing keyboard focus to OK buttons (#9915) (2.4.11)
* Thu Sep  6 2001 mvidner@suse.cz
- Dialog size and spacing fixes (for ncurses). (2.4.10)
* Mon Sep  3 2001 mvidner@suse.cz
- Use yast2-config-runlevel.
- Start portmap only if not running already (Bug #9999).
- Strip a trailing slash off pathnames (it confused "rcnfs status").
- 2.4.9
* Thu Aug 30 2001 ro@suse.de
- added <libycp-devel> to neededforbuild (for testsuite)
* Thu Aug 23 2001 mvidner@suse.cz
- Added documentation in a devel subpackage (2.4.7)
* Tue Aug 21 2001 mvidner@suse.cz
- Only one <p> per string. (2.4.6)
* Tue Aug  7 2001 mvidner@suse.cz
- Changed from RPM Requires to require.ycp.
- 2.4.5
* Mon Jul 30 2001 mvidner@suse.cz
- Turned off autoheader.
- UI bug in test suite: sformat(UI(_(...))) -> sformat(_(...))
- Replaced _("&OK") by OKButtonLabel() etc.
- Unified the buttons to Add-Edit-Delete.
- Made keyboard shortcuts unique.
- version 2.4.4
* Tue Jul 24 2001 mvidner@suse.cz
- Fixed a stupid error in the specfile.
- version 2.4.3
* Mon Jul 23 2001 mvidner@suse.cz
- Fixed calling the writing function, fixed obsolete Mkdir call.
- added a testsuite
- Requires portmap
- version 2.4.2
* Thu Jul 19 2001 msvec@suse.cz
- correct textdomain
- correct provides
- version 2.4.1
* Wed Jul 18 2001 msvec@suse.cz
- split of the yast2-config-network
- version 2.4.0
